==> zio-aws-kafka_2.13-5.17.104.3-sources.jar: zio/aws/kafka/model/DescribeClusterRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeClusterRequest = {
    import DescribeClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
      .builder()
      .clusterArn(__string.unwrap(clusterArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeClusterRequest.ReadOnly =
    zio.aws.kafka.model.DescribeClusterRequest.wrap(buildAwsValue())
}
object DescribeClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeClusterRequest =
      zio.aws.kafka.model.DescribeClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ) extends zio.aws.kafka.model.DescribeClusterRequest.ReadOnly {
    override val clusterArn: __string =
      zio.aws.kafka.model.primitives.__string(impl.clusterArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ): zio.aws.kafka.model.DescribeClusterRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.20.7.1-sources.jar: zio/aws/kafka/model/DescribeClusterRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeClusterRequest = {
    import DescribeClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeClusterRequest.ReadOnly =
    zio.aws.kafka.model.DescribeClusterRequest.wrap(buildAwsValue())
}
object DescribeClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeClusterRequest =
      zio.aws.kafka.model.DescribeClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ) extends zio.aws.kafka.model.DescribeClusterRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterRequest
  ): zio.aws.kafka.model.DescribeClusterRequest.ReadOnly = new Wrapper(impl)
}
